SystemOrganization addCategory: #'StyleProfile-Basic-Locator'!
SystemOrganization addCategory: #'StyleProfile-DAO'!
SystemOrganization addCategory: #'StyleProfile-Basic-Locator-Tests'!

Object subclass: #BaseDAO
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-DAO'!

!BaseDAO methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 21:11'!
connection

	^ ConnectionServiceLocator instance connection
! !

Object subclass: #ConnectionServiceLocator
	instanceVariableNames: 'connectionStrategy'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Basic-Locator'!

ConnectionServiceLocator class
	instanceVariableNames: 'uniqueInstance connectionSettings'!

ConnectionServiceLocator class
	instanceVariableNames: 'uniqueInstance connectionSettings'!

!ConnectionServiceLocator class methodsFor: 'instance creation' stamp: 'IgorArouca 3/14/2013 08:58'!
instance

	^ uniqueInstance ifNil: [ uniqueInstance := self basicNew initialize ]
! !

!ConnectionServiceLocator class methodsFor: 'instance creation' stamp: 'IgorArouca 3/14/2013 08:59'!
new

	^ self shouldNotImplement
! !

!ConnectionServiceLocator methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:47'!
connection

	connectionStrategy ifNil: [
		^ self error: 'Please use the #connectionStrategy: method to tell me how I should get a connection for you'
	].

	^ connectionStrategy connection
! !

!ConnectionServiceLocator methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:16'!
connectionStrategy: aConnectionStrategy

	connectionStrategy := aConnectionStrategy
! !

Object subclass: #ConnectionStrategy
	instanceVariableNames: 'connectionSettings'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Basic-Locator'!

!ConnectionStrategy class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 18:33'!
newConnectionSettings: aStream

	^ super new connectionSettings: (self privateRetrieveConnectionSettingsDictionaryFrom: aStream)
! !

!ConnectionStrategy class methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 20:27'!
privateRetrieveConnectionSettingsDictionaryFrom: aStream
	"This method encapsulates the reading operation from the stream, which should follow the format defined by the input file used to store the connecion settings"
	
	^ Dictionary readFrom: aStream
! !

!ConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 16:48'!
connection

	^ self subclassResponsibility
! !

!ConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 18:28'!
connectionSettings: aDictionary

	connectionSettings := aDictionary
! !

ConnectionStrategy subclass: #DBXManualConnectionStrategy
	instanceVariableNames: 'service'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Basic-Locator'!

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 21:17'!
connection

	| connection |

	connection := DBXConnection platform: DBXMySQLBackend new settings: self connectionSettings.
	connection connect.
	connection reOpen.

	^ connection
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:55'!
connectionSettings

	^ DBXConnectionSettings
		host: self host
		port: self port
		database: self database
		userName: self user
		userPassword: self password
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:53'!
database

	^ connectionSettings at: #database
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:53'!
host

	^ connectionSettings at: #host
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:53'!
password

	^ connectionSettings at: #password
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:54'!
port

	^ connectionSettings at: #port
! !

!DBXManualConnectionStrategy methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 19:54'!
user

	^ connectionSettings at: #database
! !

TestCase subclass: #ConnectionServiceLocatorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'StyleProfile-Basic-Locator-Tests'!

!ConnectionServiceLocatorTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 20:36'!
connectionSettings

	| settingsDict settingsStream tempStream |

	settingsDict := Dictionary new
		at: #host put: '127.0.0.1';
		at: #port put: '3306';
		at: #database put: 'information_schema';
		at: #user put: 'root';
		at: #password put: '';
		yourself.

	tempStream := String new writeStream.
	settingsDict storeOn: tempStream.

	^ ReadStream on: tempStream contents
! !

!ConnectionServiceLocatorTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 20:54'!
testConnection

	| strategy connection locator result |

	strategy := DBXManualConnectionStrategy newConnectionSettings: self connectionSettings.

	"Sets the default service to connect to the database above"
	locator := ConnectionServiceLocator instance connectionStrategy: strategy.

	"The returned connection is eady to receive queries to be executed agains the db"
	connection := locator connection.

	"Runs a simple query to test connection"
	result := connection execute: 'select * from engines'.

	self assert: result rows isEmpty equals: false. 

	"Closes the connection to release allocated resources"
	connection close
! !

!ConnectionServiceLocatorTest methodsFor: 'as yet unclassified' stamp: 'IgorArouca 3/23/2013 21:07'!
testConnectionWithoutStrategy

	| locator |

	locator := ConnectionServiceLocator instance.
	locator connectionStrategy: nil.

	self should: [ locator connection ] raise: Error
! !
